/*
 * Copyright (c) 2017 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/*global document, window*/

/**
 * Helpers module.
 *
 * @module app.helpers
 *
 * @namespace app.helpers
 */

// make sure that "app" namespace is created
window.app = window.app || {};

(function helpers(app) {
    'use strict';

    /**
     * Gets elements with querySelectorAll and returns them in array.
     *
     * @memberof app.helpers
     * @public
     * @param {string} selector DOM Selector.
     * @param {HTMLElement} [element=document] Search scope.
     * @returns {HTMLElement[]}
     */
    function getElementsInArray(selector, element) {
        return Array.prototype.slice.apply(
            (element || document).querySelectorAll(selector)
        );
    }

    /**
     * Validates provided input against it's defined type.
     * Returns results of validation.
     *
     * @memberof app.helpers
     * @public
     * @param {HTMLElement} input
     * @returns {boolean}
     */
    function validateEmailField(input) {
        return input.value.trim() && input.checkValidity();
    }

    app.helpers = {
        getElementsInArray: getElementsInArray,
        validateEmailField: validateEmailField
    };

}(window.app));
